datas = {
    "好评": {
        "开始": [
            "考虑买这个$之前我是有担心过的，因为我不知道$的质量和品质怎么样，但是看了评论后我就放心了。",
            "买这个$之前我是有看过好几家店，最后看到这家店的评价不错就决定在这家店买 ",
            "看了好几家店，也对比了好几家店，最后发现还是这一家的$评价最好。",
            "看来看去最后还是选择了这家。",
            "之前在这家店也买过其他东西，感觉不错，这次又来啦。"
        ],
        "中间": [
            "收到货后我非常的开心，因为$的质量和品质真的非常的好！",
            "拆开包装后惊艳到我了，这就是我想要的$!",
            "快递超快！包装的很好！！很喜欢！！！",
            "包装的很精美！$的质量和品质非常不错！",
            "收到快递后迫不及待的拆了包装。$我真的是非常喜欢"
        ],
        "结束": [
            "经过了这次愉快的购物，我决定如果下次我还要买$的话，我一定会再来这家店买的。",
            "不错不错！",
            "我会推荐想买$的朋友也来这家店里买",
            "真是一次愉快的购物！",
            "大大的好评!以后买$再来你们店！(￣▽￣)"
        ]
    },
    "差评": {
        "开始": [
            "我真是瞎了眼，竟然在这家店里面买$ ",
            "我还可以说什么？ 这家店的$简直不行 ",
            "这是我买到的最差的$ "
        ],
        "中间": [
            "我以后都不会再来这家店里买东西了！",
            "再也不来了，不来了！",
            "$的质量真的非常的不行！"
        ],
        "结束": [
            "对这家店的$失望透顶!",
            "这家店给我对于$能做成这样刷新了世界观!",
            "真是一次糟心的购物！"
        ]
    }
}